iterationtools.iterate_logical_voice_from_component
===================================================

.. autofunction:: abjad.tools.iterationtools.iterate_logical_voice_from_component.iterate_logical_voice_from_component
